@@ -1,18 +1,18 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2011 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::OpenSsh ;
-{
-  $Config::Model::Backend::OpenSsh::VERSION = '1.230_05';
+BEGIN {
+  $Config::Model::Backend::OpenSsh::VERSION = '1.211';
 }
 
-use Mouse ;
+use Moose ;
 extends "Config::Model::Backend::Any" ;
 
 has 'current_node'  => ( 
@@ -38,29 +38,34 @@ my @dispatch = (
     qr/\w/                     => 'assign',
 );
 
-sub suffix {return '';}
-
-sub read {
+sub read_ssh_file {
     my $self = shift ;
     my %args = @_ ;
     my $config_root = $args{object}
       || croak __PACKAGE__," read_ssh_file: undefined config root object";
+    my $dir = $args{root}.$args{config_dir} ;
+    my $skip_notes = $args{skip_notes} || 0 ;
 
-    $logger->info("loading config file ".$args{file_path});
-
-    my $fh = $args{io_handle} ;
-    if (not defined $fh) {
-        $logger->warn("cannot read $args{file_path}");
-        return 0;
+    unless (-d $dir ) {
+	$logger->info("read_ssh_file: unknown config dir $dir");
+	return 0;
     }
 
+    my $file = $dir.'/'.$args{file} ;
+    unless (-r "$file") {
+	$logger->info("read_ssh_file: unknown file $file");
+	return 0;
+    }
+
+    $logger->info("loading config file $file");
+
+    my $fh = new IO::File $file, "r"  
+        || die __PACKAGE__," read_ssh_file: can't open $file:$!";
+
     my @lines = $fh->getlines ;
     # try to get global comments (comments before a blank line)
     $self->read_global_comments(\@lines,'#') ;
 
-    # need to reset this when reading user ssh file after system ssh file
-    $self->current_node($config_root) ;
-
     my @assoc = $self->associates_comments_with_data( \@lines, '#' ) ;
     foreach my $item (@assoc) {
         my ( $vdata, $comment ) = @$item;
@@ -70,7 +75,7 @@ sub read {
         my $i = 0;
         while ( $i < @dispatch ) {
             my ( $regexp, $sub ) = @dispatch[ $i++, $i++ ];
-            if ( $k =~ $regexp and $self->can($sub)) {
+            if ( $k =~ $regexp ) {
                 $logger->trace("read_ssh_file: dispatch calls $sub");
                 $self->$sub( $config_root, $k, \@v, $comment );
                 last;
@@ -83,29 +88,10 @@ sub read {
     return 1;
 }
 
-sub ssh_write {
-    my $self = shift ;
-    my %args = @_ ;
-
-    my $config_root = $args{object}
-      || croak __PACKAGE__," ssh_write: undefined config root object";
-
-    $logger->info("writing config file $args{file_path}");
-
-    my $ioh = $args{io_handle} || croak __PACKAGE__," ssh_write: undefined io_handle";;
-    $self->write_global_comment($ioh,'#') ;
-
-    my $result = $self->write_node_content($config_root,$args{ssh_mode});
-
-    $ioh->print ($result);
-
-    return 1;
-}
-
 sub assign {
     my ($self,$root, $raw_key,$arg,$comment) = @_ ;
     $logger->debug("assign: $raw_key @$arg # $comment");
-
+    $self->current_node($root) unless defined $self->current_node ;
 
     # keys are case insensitive, try to find a match
     my $key = $self->current_node->find_element ($raw_key, case => 'any') ;
@@ -139,29 +125,9 @@ sub assign {
 
 sub write_line {
     my ($self, $k, $v, $note) = @_ ;
-    return '' unless length($v) ;
     return $self->write_data_and_comments( undef, '#',sprintf("%-20s %s",$k,$v),$note) ;
 }
 
-sub write_list {
-    my ($self,$name,$mode,$elt) = @_;
-    my @r = map { $self->write_line($name,$_->fetch($mode), $_->annotation) ;} $elt->fetch_all() ;
-    return join('',@r) ;
-}
-
-
-sub write_list_in_one_line {
-    my ($self,$name,$mode,$elt) = @_;
-    my @v = $elt->fetch_all_values(mode => $mode) ;
-    return $self->write_line($name,join(' ',@v)) ;    
-}
-
-# list there list element that must be written on one line with items
-# separated by a white space
-my %list_as_one_line = (
-    'AuthorizedKeysFile' => 1 ,
-) ;
-
 sub write_node_content {
     my $self= shift ;
     my $node = shift ;
@@ -191,19 +157,18 @@ sub write_node_content {
 	    if (defined $v and $elt->value_type eq 'boolean') {
 		$v = $v == 1 ? 'yes':'no' ;
 	    }
-	    $result .= $self->write_line($name,$v,$note);
+	    $result .= $self->write_line($name,$v,$note) if defined $v;
 	}
 	elsif    ($type eq 'check_list') { 
 	    my $v = $elt->fetch($mode) ;
-	    $result .= $self->write_line($name,$v,$note);
+	    $result .= $self->write_line($name,$v,$note) if defined $v and $v;
 	}
 	elsif ($type eq 'list') { 
 	    $result .= $self->write_data_and_comments(undef,'#', undef, $note) ; 
-	    $result .= $list_as_one_line{$name} ? $self->write_list_in_one_line($name,$mode,$elt)
-                    :                             $self->write_list($name,$mode,$elt) ;
+	    map { $result .= $self->write_line($name,$_->fetch($mode), $_->annotation) ;} $elt->fetch_all() ;
 	}
 	elsif ($type eq 'hash') {
-	    foreach my $k ( $elt->fetch_all_indexes ) {
+	    foreach my $k ( $elt->get_all_indexes ) {
 		my $o = $elt->fetch_with_id($k);
 		my $v = $o->fetch($mode) ;
 		$result .=  $self->write_line($name,"$k $v", $o->annotation) ;
@@ -217,8 +182,6 @@ sub write_node_content {
     return $result.$match ;
 }
 
-no Mouse;
-
 1;
 
 =head1 NAME
@@ -241,4 +204,4 @@ Dominique Dumont, (ddumont at cpan dot org)
 
 =head1 SEE ALSO
 
-L<cme>, L<Config::Model>, L<Config::Model::OpenSsh>
+L<config-edit>, L<Config::Model>,
